distinct_errs_collection

Function distinct_errs_collection 

pub(crate) fn distinct_errs_collection<'a, T: RenderTimestamp>(
    errs: VecCollection<'a, T, DataflowErrorSer, Diff>,
) -> VecCollection<'a, T, DataflowErrorSer, Diff>
Rewrites an error collection to hold each of its errors once.

Costs an arrangement more than distinct_arranged_errs, which reuses the arrangement its input already has.